National Child Development Study: a sample of the fifth wave of data collection
ncds_5.RdThis database is a sample of the fifth wave of data collection of the National Child Development Study (NCDS) started in 1958 (https://cls.ucl.ac.uk/cls-studies/1958-national-child-development-study/). The NCDS project is a continuing survey which follows the lives of over 17,000 people born in England, Scotland and Wales in a same week of the year 1958.
Format
A data.frame with 365 participants (rows) and 6 variables
- ncdsid
the anonymised ncds identifier
- gender
the gender of the participant stored in a 2-levels factor:
1for male,2for female- RG91
the RG social class 91 scale coded as a 7-levels factor:
10for professional educations,20for managerial and technical occupations,31for skilled non-manual occupations,32for skilled manual occupations,40for party-skilled occupations,50for unskilled occupations50, and0when the scale was not applicable to the participant. This variable is complete.- health
the health status of the participant stored in a 4 ordered levels factor:
1for excellent,2for good,3for fair,4for poor. This variable has 2 NAs.- employ
the employment status at inclusion stored in a 7-levels factor:
1for unemployed status,2for govt sheme,3for full-time education,4for housework or childcare,5for sick or handicapped,6for other,7if employed between 16 and 33. This variable has 58 NAs.- study
a 2-level factor equals to
1for participant with completed graduate studies or2otherwise