Learn R Programming

OTrecod (version 0.1.2)

transfo_quali: transfo_quali()

Description

A function that transforms a factor of n(>1) levels in (n-1) binary variables.

Usage

transfo_quali(x, labx = NULL)

Value

A matrix of (n-1) binary variables

Arguments

x

a factor

labx

a new label for the generated binary variables (By default the name of the factor is conserved)

Author

Gregory Guernec

otrecod.pkg@gmail.com

Examples

Run this code

treat <- as.factor(c(rep("A", 10), rep("B", 15), rep("C", 12)))
treat_bin <- transfo_quali(treat, "trt")

Run the code above in your browser using DataLab