powered by
A function that transforms a factor of n(>1) levels in (n-1) binary variables.
transfo_quali(x, labx = NULL)
A matrix of (n-1) binary variables
a factor
a new label for the generated binary variables (By default the name of the factor is conserved)
Gregory Guernec
otrecod.pkg@gmail.com
treat <- as.factor(c(rep("A", 10), rep("B", 15), rep("C", 12))) treat_bin <- transfo_quali(treat, "trt")
Run the code above in your browser using DataLab